safe_cmd_util (rebar_safe v1.0.1)
View SourceSummary
Functions
Returns the path to the project's SAFE config file.
Build the SAFE config from rebar3 state, with debug output.
Returns a config_path spec for an existing config file, with debug output.
Functions
Returns the path to the project's SAFE config file.
-spec get_config(safe_rebar_interface:state(), boolean()) -> {ok, map()} | {error, term()}.
Build the SAFE config from rebar3 state, with debug output.
Returns a config_path spec for an existing config file, with debug output.